活着 (豆瓣)
Description: 活着电影简介和剧情介绍,活着影评、图片、预告片、影讯、论坛、在线购票
Keywords: 活着,活着,活着影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.30豆瓣电影Top250

# 活着 (1994)

导演: 张艺谋
编剧: 芦苇 / 余华
主演: 葛优 / 巩俐 / 姜武 / 牛犇 / 郭涛 / 张璐 / 倪大红 / 肖聪 / 董飞 / 刘天池 / 董立范 / 黄宗洛 / 刘燕瑾 / 李连义 / 杨同顺
类型: 剧情 / 家庭 / 历史
制片国家/地区: 中国大陆 / 中国香港
语言: 汉语普通话
上映日期: 1994-06-30(中国香港) / 1994-05-17(戛纳电影节)
片长: 132分钟
又名: 人生 / Lifetimes / To Live
IMDb: tt0110081
豆瓣评分
引用
9.3
794127人评价
5星
69.7%
4星
26.0%
3星
3.9%
2星
0.3%
1星
0.1%
好于 99% 剧情片
好于 99% 历史片
想看 看过
评价:
推荐

## 活着的剧情简介 · · · · · ·

根据余华同名小说改编。
富少福贵（葛优）嗜赌成性，妻子家珍（巩俐）屡劝无果后带着女儿凤霞离开了他，当夜，福贵输光所有家产气死父亲，被迫靠变卖母亲首饰租间破屋过活。一年后，家珍手拉凤霞怀抱刚出世的儿子有庆回到家中，福贵痛改前非，开始靠演皮影戏过起安份守己的日子。
但好景不常，内战时期，福贵被国民党抓去当劳工，一番辗转终回到家乡与一家人团圆后，凤霞因病变成哑巴，而在后来的大跃进运动和文化大革命中，他虽获某些小福，逆境却也一直与他如影相随。 ©豆瓣

## 活着的演职员 · · · · · · ( 全部 32 )

- 张艺谋 导演
- 葛优 饰 福贵
- 巩俐 饰 家珍
- 姜武 饰 二喜
- 牛犇 饰 镇长
- 郭涛 饰 春生

## 活着的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片769 · 添加 )

## 活着的获奖情况 · · · · · · ( 全部 )

- 第47届戛纳电影节
- 主竞赛单元 金棕榈奖(提名)
- 张艺谋

- 第52届金球奖
- 电影类 最佳外语片(提名)

- 第48届英国电影学院奖
- 电影奖 最佳非英语片
- 邱复生 / 张艺谋

## 喜欢这部电影的人也喜欢 · · · · · ·

  末代皇帝

  饮食男女

  一一

  茶馆

  雨人

  海边的曼彻斯特

  霸王别姬

  寻梦环游记

  岁月神偷

  小偷家族

我要写短评

## 活着的短评 · · · · · · ( 全部 170400 条 )

热门 / 最新 / 好友

### 5598 有用 西楼尘 看过 2015-06-23 22:22:35

国家走了一小段弯路，对于一代人就是蹉跎了一辈子。生活不易，还是得这么活着。笑中带泪，死人堆里暗暗许下活着的誓约，可谁也不曾想大环境下生活的艰辛。国师在第五代导演最好的时期奉献了极其有温度的作品。经年以后，鹤发的富贵摇着蒲扇回想那天不让有庆上学，少买几个馒头就好了，可生活不曾回头。

### 4005 有用 Lan~die 看过 2009-01-25 17:28:31

活着就是受罪 活着就是劳累 活着就是互相折磨 活着就是不对 活着就是受罪 活着就是劳累 活着还得互相安慰 活着就会憔悴 活着就是受罪 活着就是劳累 活着就得拼命挣扎 活着就得干脆 ——尹吾 你笑着流出了泪

### 7207 有用 林||我们谈什么都像谈死！ 看过 2008-03-29 15:29:10

年代记实录，看了让人不舒服，特别是里面的台词，虽然他们在拼尽全力的活着，可是却又显得如此可笑和悲凉。“小鸡长大了就变成了鹅，鹅长大了就变成了羊，羊长大了就变成了牛，牛长大了就是共产主义了。”

### 6110 有用 艾小柯 看过 2006-06-16 01:33:13

个人认为是张义谋最好的电影。

### 3644 有用 momo 看过 2016-10-23 09:48:39

演员选得很好，巩俐演啥像啥。但整体没有小说感人，可能小说太残酷了吧。兴，百姓苦；亡，百姓苦。活到最后的人，往往最痛苦。

> 更多短评 170400条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 活着的影评 · · · · · · ( 全部 2857 条 )

热门 / 最新 / 好友
八月槎 2006-03-30 00:39:16

## 《活着》——《在细雨中呼喊》后的余华与《英雄》前的张艺谋

这篇影评可能有剧透

电梯：http://movie.douban.com/review/1034597/?start=100 电影《活着》，1994年出品，制片人：邱复生；编剧：余华、芦苇；剧本定稿：芦苇（盗版碟字幕模糊，不知是否准确。）；电影音乐：赵季平；导演：张艺谋。 进入电影，马上就会感到同阅读小说的鲜明差异，余华的叙述角度... (展开)
4821 128 332回应 收起
子非鱼 2005-10-02 13:08:21

## 《活着》的失败与伟大

我怜惜的不是家珍，虽然在书里为她唏嘘过，不是福贵，多少有自己造孽的成分，不是有庆，小说里是因抽血而失血过多夭亡，电影中未免过于血腥，砖墙倒塌后的血肉模糊，真实的...我怜惜的是从头至尾，一句话也未曾说过，想说却不能说的凤霞。她不是无声的来到这个世界，虽然... (展开)
2417 202 257回应 收起
私享史 2007-03-01 01:35:36

## 《活着》到底为什么没能活？

网上一直流传着一个“中国大陆十大禁片”的帖子，每部片子被禁的理由都写得有鼻子有眼，有些理由大抵是站得住脚的，有些则不然，比如说《活着》是“诋毁社会主义法制，诋毁政党执政能力”，这不是瞎掰么？都什么年代了，封杀一部电影还犯得着如此上纲上线？我向来很不喜欢网上... (展开)
1388 694 427回应 收起
冷翳 2007-07-05 16:47:40

## 命运的玩偶

看《活着》，自然会想到《霸王别姬》，同样是这么风风雨雨几十年的人生，同样是跨越了最动荡变化最快的那些个历史时期，人物同样是渺小无奈，在命运历史面前毫无选择（包括《霸》里面蝶衣的死，看似是他自己选择的，其实不然，霸王别姬，不能再重演，虞姬除了永别还能有什么选... (展开)
997 69 93回应 收起
小千 2007-11-13 21:27:17

## 活着的叙事结构及视听语言分析

叙事结构 在我看来，影片的结构非常清晰，而且有其独特的艺术特色――明暗线交织，情节步步深入，环环相扣，过渡和谐而情节丰满。 　　明线则为导演为影片分的四个部分：四十年代，五十年代，六十年代，以后。通过这种线型的结构形式，把故事放在几个大的时代背景下，以线型... (展开)
724 26 41回应 收起
大欣子 2006-10-08 12:21:10

## 活着～皮影戏

从小说《活着》中的由第三人称来讲述福贵的人生故事，到电影《活着》中由第一人称自己演绎故事，是本剧电影剧本的一项重大的改变。要实现这种人称的转变，可行的方式也许有许多种。张艺谋和他的剧组，选择了增加“皮影戏”，这条极有意思的情节线，来成就这个转变。我试从一下... (展开)
254 16 34回应 收起
桃子好吃 2016-06-02 15:50:37

## 活着，以一种向死而生的姿态

这篇影评可能有剧透

活着本身就不是一件易事。活着，有时候比死去更需要勇气和决心。有句老话说得好，好死不如赖活着。与其痛快地结束生命倒不如好好活着。我们在观看一部电影时常常喜欢将他和原著作对比从而来评定它的艺术价值，我觉得这样的方式是有它的不可取之处的。小说与电影本是两个独立的... (展开)
423 35 119回应 收起
LOOK 2019-01-18 10:16:29

## 简单提一下影片的症结所在

影片《活着》的高潮是凤霞生孩子遭遇大出血，大特写镜头逼视下的家珍泪如雨下，富贵与二喜急得团团转，本来被拉来救人的王教授因为一口气吃了七个包子奄奄一息，无法动弹。最终众人只能眼见着家珍惨烈异常地死去。这是火爆煽情、催人泪下的一场戏。但是这场戏与余华原小说的整... (展开)
207 152 146回应 收起
西米 2007-12-31 23:40:30

## 浓缩并不一定就是精华

或者，先看电影《活着》再看小说，会是更好的选择。偏偏先是沉浸在余华惨烈的“暴力美学”当中，而后来看被称为张艺谋经典之作的电影《活着》，心中的失落便无可抑制。尽管说，大荧幕的多媒体表现方式，让《活着》更加地形象；但在文字的意蕴深远，却比声色更足以给人独自品味... (展开)
116 7 19回应 收起

> 更多影评 2857篇

添加新讨论

## 讨论区 · · · · · ·

说句可能被封号的话 | 来自Cut | 55 回应 | 2022-11-24 17:51:54
龙二被枪决前回头对富贵喊了什么？ | 来自APOLLO | 11 回应 | 2022-11-23 23:10:10
能拍出活着的人，为什么会拍出三枪 | 来自随遇而安 |  | 2022-11-23 19:11:58
同样是表现苦难，活着vs钢琴家 | 来自随遇而安 |  | 2022-11-21 08:10:11
徐福贵的错误 | 来自🌰 | 7 回应 | 2022-11-20 03:08:51

> 去这部影片的讨论区（全部467条）

## 关于《活着》的问题 · · · · · · ( 全部29个 )

- 有庆之死为什么这么改编？ 12人回答
- 龙二被枪决之前跟富贵说了什么？ 7人回答

> 全部29个问题

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 【内牛满面】 (影志)
- 北京电影学院硕士要看的100部电影 (悲`馨)
- 一禁成名 (影志)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  4分钟前 想看
- 沉默是最好的
  8分钟前 看过
- 大葱
  9分钟前 想看

1253869人看过 / 475475人想看

订阅活着的评论:
feed: rss 2.0